@@ -40,7 +40,15 @@ class ParamsException(Exception):
 
 class LowBalanceException(Exception):
     """
-    API tool balance is low
+    API: Tool balance is low
+    """
+
+    pass
+
+
+class FrameException(Exception):
+    """
+    UI: Captcha is probably inside iframe
     """
 
     pass
